@@ -22,7 +22,7 @@ import os
 import configparser
 
 def read(fname):
-    return open(os.path.join(os.path.dirname(__file__), fname)).read()
+    return open(os.path.join(os.path.dirname(__file__), fname), encoding="UTF-8").read()
 
 config = configparser.ConfigParser()
 config.readfp(open('tryton.cfg'))
